@@ -1,4 +1,5 @@
 import os
+import sys
 import shutil
 import subprocess
 import tempfile
@@ -52,12 +53,12 @@ def install():
             raise Exception(message)
 
         else:
-            exe = os.path.join(CVARS['exec_prefix'], 'gpython.exe')
+            exe = os.path.join(os.path.dirname(sys.executable), 'gpython.exe')
             shutil.copyfile(os.path.join(tempdir, 'gpython.exe'), exe)
 
         proc.stdout.close()
 
 
 def uninstall():
-    exe = os.path.join(CVARS['exec_prefix'], 'gpython.exe')
+    exe = os.path.join(os.path.dirname(sys.executable), 'gpython.exe')
     os.unlink(exe)
